# pyAFQ
Automated Fiber Quantification ... in Python.

For details, see [Documentation](https://yeatmanlab.github.io/pyAFQ)

For further analysis of results, see [AFQ-Insight](https://github.com/richford/AFQ-Insight)

## Citing _pyAFQ_

If you use _pyAFQ_ in a scientific publication, please cite our paper:

Kruper, J., Yeatman, J. D., Richie-Halford, A., Bloom, D., Grotheer, M., Caffarra, S., Kiar, G., Karipidis, I. I., Roy, E., Chandio, B. Q., Garyfallidis, E., & Rokem, A.
[Evaluating the Reliability of Human Brain White Matter Tractometry](https://doi.org/10.52294/e6198273-b8e3-4b63-babb-6e6b0da10669).
DOI:10.52294/e6198273-b8e3-4b63-babb-6e6b0da10669

```
@article {Kruper2021-xb,
  title     = "Evaluating the reliability of human brain white matter
               tractometry",
  author    = "Kruper, John and Yeatman, Jason D and Richie-Halford, Adam and
               Bloom, David and Grotheer, Mareike and Caffarra, Sendy and Kiar,
               Gregory and Karipidis, Iliana I and Roy, Ethan and Chandio,
               Bramsh Q and Garyfallidis, Eleftherios and Rokem, Ariel",
  journal   = "Apert Neuro",
  publisher = "Organization for Human Brain Mapping",
  volume    =  1,
  number    =  1,
  month     =  nov,
  year      =  2021,
  doi       =  10.52294/e6198273-b8e3-4b63-babb-6e6b0da10669,
}
```
